confita

package module
v0.0.0-...-f81d64f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2024 License: MIT Imports: 5 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SetNewLoader

func SetNewLoader(l Loader) func()

SetNewLoader sets loader l as global.

Return function on calling it will set old global loader back.

Types

type Loader

type Loader interface {
	// Load analyses all the Fields of the given struct for a "config" tag and queries each backend
	// in order for the corresponding key. The given context can be used for timeout and cancelation.
	Load(ctx context.Context, to interface{}) error
}

func Get

func Get() (l Loader)

Get return global loader.

Jump to